<?php

namespace FiloBlu\DynamicCustomOptions\Block\Adminhtml\DynamicCustomOptions\Edit\Tab;

use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Form\Generic;
use Magento\Backend\Block\Widget\Tab\TabInterface;
use Magento\Framework\Data\FormFactory;
use Magento\Framework\Registry;

class Main extends Generic implements TabInterface {

    protected $_systemStore;

    /**
     * Constructor
     *
     * @param Context $context
     * @param Registry $registry
     * @param FormFactory $formFactory
     * @param array $data
     */
    public function __construct(
    Context $context, Registry $registry, FormFactory $formFactory, \Magento\Store\Model\System\Store $systemStore, array $data = []
    ) {
        $this->_systemStore = $systemStore;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * {@inheritdoc}
     */
    public function getTabLabel() {
        return __('Dynamic Custom Options Information');
    }

    /**
     * {@inheritdoc}
     */
    public function getTabTitle() {
        return __('Dynamic Custom Options Information');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab() {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden() {
        return false;
    }

    /**
     * Prepare form before rendering HTML
     *
     * @return Generic
     */
    protected function _prepareForm() {
        $model = $this->_coreRegistry->registry('current_dynamiccustomoptions');

        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create();
        $form->setHtmlIdPrefix('dynamiccustomoptions_');

        $fieldset = $form->addFieldset('base_fieldset', ['legend' => __('General Information')]);

        if ($model->getId()) {
            $fieldset->addField('dynamiccustomoptions_id', 'hidden', ['name' => 'dynamiccustomoptions_id']);
        }

        $fieldset->addField(
                'is_active', 'select', [
            'label' => __('Status'),
            'title' => __('Status'),
            'name' => 'is_active',
            'required' => true,
            'options' => ['1' => __('Active'), '0' => __('Inactive')]
                ]
        );
        
        $fieldset->addField(
                'is_cron_active', 'select', [
            'label' => __('Cron'),
            'title' => __('Cron'),
            'name' => 'is_cron_active',
            'required' => true,
            'options' => ['1' => __('Active'), '0' => __('Inactive')]
                ]
        );
        
        $fieldset->addField(
                'do_actions_on_save', 'select', [
            'label' => __('Do Actions On Save'),
            'title' => __('Do Actions On Save'),
            'name' => 'do_actions_on_save',
            'required' => true,
            'options' => ['1' => __('Yes'), '0' => __('No')]
                ]
        );


        if (!$model->getId()) {
            $model->setData('is_active', '1');
            $model->setData('is_cron_active', '1');
            $model->setData('do_actions_on_save', '0');
        }

        $fieldset->addField(
                'name', 'text', ['name' => 'name', 'label' => __('Name'), 'title' => __('Name'), 'required' => true]
        );

        $fieldset->addField(
                'description', 'textarea', [
            'name' => 'description',
            'label' => __('Description'),
            'title' => __('Description'),
            'style' => 'height: 100px;'
                ]
        );

        if (!$model->getId()) {
            $fieldset->addField(
                    'json_config', 'textarea', [
                'name' => 'json_config',
                'label' => __('Json Custom Options Config'),
                'title' => __('Json Custom Options Config'),
                'style' => 'height: 300px;',
                'required' => true,
                'after_element_html' => '<p class="nm"><small>' . ' <a href="http://jsonviewer.stack.hu/" target="_blank" >Human Readable Json</a> ' . '</small></p>',
                    ]
            );
        } else {
            $fieldset->addField(
                    'json_config', 'textarea', [
                'name' => 'json_config',
                'label' => __('Json Custom Options Config'),
                'title' => __('Json Custom Options Config'),
                'style' => 'height: 300px;',
                'readonly' => true,
                'required' => true,
                'after_element_html' => '<p class="nm"><small>' . ' <a href="http://jsonviewer.stack.hu/" target="_blank" >Human Readable Json</a> ' . '</small></p>',
                    ]
            );
        }



//        if (!$this->_storeManager->isSingleStoreMode()) {
//            $field = $fieldset->addField(
//                'store_ids', 'multiselect', [
//                'name' => 'store_ids[]',
//                'label' => __('Assign to Store Views'),
//                'title' => __('Assign to Store Views'),
//                'required' => true,
//                'values' => $this->_systemStore->getStoreValuesForForm(false, true)
//                    ]
//            );
//            $renderer = $this->getLayout()->createBlock(
//                    'Magento\Backend\Block\Store\Switcher\Form\Renderer\Fieldset\Element'
//            );
//            $field->setRenderer($renderer);
//        }
//        $fieldset->addField('sort_order', 'text', ['name' => 'sort_order', 'label' => __('Priority')]);
//
//        $dateFormat = $this->_localeDate->getDateFormat(\IntlDateFormatter::SHORT);
//        $fieldset->addField(
//            'from_date',
//            'date',
//            [
//                'name' => 'from_date',
//                'label' => __('From'),
//                'title' => __('From'),
//                'input_format' => \Magento\Framework\Stdlib\DateTime::DATE_INTERNAL_FORMAT,
//                'date_format' => $dateFormat
//            ]
//        );
//        $fieldset->addField(
//            'to_date',
//            'date',
//            [
//                'name' => 'to_date',
//                'label' => __('To'),
//                'title' => __('To'),
//                'input_format' => \Magento\Framework\Stdlib\DateTime::DATE_INTERNAL_FORMAT,
//                'date_format' => $dateFormat
//            ]
//        );
//
        $form->setValues($model->getData());

        if ($model->isReadonly()) {
            foreach ($fieldset->getElements() as $element) {
                $element->setReadonly(true, true);
            }
        }

        $this->setForm($form);

        $this->_eventManager->dispatch('adminhtml_dynamiccustomoptions_edit_tab_main_prepare_form', ['form' => $form]);

        return parent::_prepareForm();
    }

}
