<?php

namespace FiloBlu\DynamicCustomOptions\Block\Adminhtml\DynamicCustomOptions\Edit\Tab;

use Magento\Backend\Block\Widget\Tab\TabInterface;

class Products extends \Magento\Backend\Block\Widget\Grid\Extended implements TabInterface {

    protected $_productCollection;

    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry;
    protected $_productMetadata;

    /**
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Data\FormFactory $formFactory
     * @param array $data
     */
    public function __construct(
    \Magento\Backend\Block\Template\Context $context, \Magento\Backend\Helper\Data $backendHelper, \Magento\Framework\Registry $registry, \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollectionFactory, \Magento\Framework\App\ProductMetadataInterface $productMetadata, array $data = []
    ) {
        $this->_productCollection = $productCollectionFactory;
        $this->_coreRegistry = $registry;
        $this->_productMetadata = $productMetadata;
        parent::__construct($context, $backendHelper, $data);
    }

    public function _construct() {
        parent::_construct();
        $this->setId('productsGrid');
        $this->setDefaultSort('product_id');
        $this->setDefaultDir('ASC');
//        $this->setUseAjax(true);
//        if ($this->getStore()->getStoreId()) {
//            $this->setDefaultFilter(['in_tags'=>1]);
//        }
    }

    /**
     * prepare the collection

     * @return $this
     */
    protected function _prepareCollection() {
        if (!$this->_coreRegistry->registry('current_dynamiccustomoptions')->getId()) {
            return $this;
        }
        $idProductEntity = ($this->_productMetadata->getEdition() == 'Enterprise' || $this->_productMetadata->getEdition() == 'B2B') ? "row_id" : "entity_id";

        $collection = $this->_productCollection->create()->addFieldToSelect(['sku']);

        $collection->getSelect()->join(
                ['dynamiccustomoptionsproducts' => $collection->getTable('filoblu_dynamiccustomoptions_products')], 'dynamiccustomoptionsproducts.product_id=' . $idProductEntity, ['product_id']
        )->where(
                'dynamiccustomoptionsproducts.dynamiccustomoptions_id = ' . $this->_coreRegistry->registry('current_dynamiccustomoptions')->getId()
        );
        
        $collection->distinct(true);

        $this->setCollection($collection);
        parent::_prepareCollection();
        return $this;
    }

    /**
     * @return $this
     */
    protected function _prepareColumns() {

        $this->addColumn(
                'product_id', [
            'header' => __('Product ID'),
            'sortable' => true,
            'index' => 'product_id',
            'type' => 'number',
            'header_css_class' => 'col-product-id',
            'column_css_class' => 'col-product-id'
                ]
        );

        $this->addColumn(
                'sku', [
            'header' => __('Sku'),
            'index' => 'sku',
            'header_css_class' => 'col-sku',
            'column_css_class' => 'col-sku'
                ]
        );


        return $this;
    }

    /**
     * {@inheritdoc}
     */
    public function getTabLabel() {
        return __('Products');
    }

    /**
     * {@inheritdoc}
     */
    public function getTabTitle() {
        return __('Products');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab() {
        return ($this->_coreRegistry->registry('current_dynamiccustomoptions')->getIsActive() && $this->_coreRegistry->registry('current_dynamiccustomoptions')->getId());
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden() {
        return !($this->_coreRegistry->registry('current_dynamiccustomoptions')->getIsActive() && $this->_coreRegistry->registry('current_dynamiccustomoptions')->getId());
    }

}
