<?php

namespace FiloBlu\DynamicCustomOptions\Model\ResourceModel;

class DynamicCustomOptions extends \Magento\Rule\Model\ResourceModel\AbstractResource {

    /**
     * Initialize main table and table id field
     *
     * @return void
     */
    protected function _construct() {
        $this->_init('filoblu_dynamiccustomoptions', 'dynamiccustomoptions_id');
    }

    public function insertMatchingProducts($data) {
        $adapter = $this->getConnection();
        $adapter->insertOnDuplicate($this->getTable('filoblu_dynamiccustomoptions_products'), $data);
    }

    public function loadMatchingProducts($dynamicCustomOptionsId) {
        $select = $this->getConnection()->select()->from(
                                $this->getTable('filoblu_dynamiccustomoptions_products'), ['product_id']
                        )
                        ->where(
                                'dynamiccustomoptions_id = :dynamiccustomoptions_id'
                        );

        $bind = ['dynamiccustomoptions_id' => $dynamicCustomOptionsId];

        $result = $this->getConnection()->fetchCol($select, $bind);

        return $result;
    }
    
    public function productHasOptions($productId) {
        $select = $this->getConnection()->select()->from(
                                $this->getTable('filoblu_dynamiccustomoptions_products'), ['product_id']
                        )
                        ->where(
                                'product_id = :product_id'
                        );

        $bind = ['product_id' => $productId];

        $result = $this->getConnection()->fetchCol($select, $bind);

        
        return ($result ? true : false);
    }
    
//    public function loadMatchingStoreIds($dynamicCustomOptionsId) {
//        $select = $this->getConnection()->select()->from(
//                                $this->getTable('filoblu_dynamiccustomoptions_products'), ['store_id']
//                        )
//                        ->where(
//                                'dynamiccustomoptions_id = :dynamiccustomoptions_id'
//                        )->distinct(true);
//
//        $bind = ['dynamiccustomoptions_id' => $dynamicCustomOptionsId];
//
//        $result = $this->getConnection()->fetchCol($select, $bind);
//
//        return $result;
//    }

    public function deleteAllIds($dynamicCustomOptionsId) {
        $adapter = $this->getConnection();
        $condition = ['dynamiccustomoptions_id=?' => $dynamicCustomOptionsId];
        $adapter->delete($this->getTable('filoblu_dynamiccustomoptions_products'), $condition);
    }
    
    public function loadCustomOptionsToDelete($dynamicCustomOptionsId) {
        $select = $this->getConnection()->select()->from(
                                $this->getTable('filoblu_dynamiccustomoptions_products'), ['option_id']
                        )
                        ->where(
                                'dynamiccustomoptions_id = :dynamiccustomoptions_id'
                        );

        $bind = ['dynamiccustomoptions_id' => $dynamicCustomOptionsId];

        $result = $this->getConnection()->fetchCol($select, $bind);

        return $result;
    }
    
    public function loadCustomOptionsToDeleteByProductIds($dynamicCustomOptionsId,$productIdsToDelete) {
        $select = $this->getConnection()->select()->from(
                                $this->getTable('filoblu_dynamiccustomoptions_products'), ['option_id']
                        )
                        ->where(
                                'dynamiccustomoptions_id = :dynamiccustomoptions_id'
                        )->where(
                                'product_id IN (?)', $productIdsToDelete
                        );

        $bind = ['dynamiccustomoptions_id' => $dynamicCustomOptionsId];

        $result = $this->getConnection()->fetchCol($select, $bind);

        return $result;
    }
    
//    public function deleteUnmatchingStoreIds($storeIdsToDelete, $dynamicCustomOptionsId) {
//        $adapter = $this->getConnection();
//        $condition = ['store_id IN(?)' => $storeIdsToDelete, 'dynamiccustomoptions_id=?' => $dynamicCustomOptionsId];
//        $adapter->delete($this->getTable('filoblu_dynamiccustomoptions_products'), $condition);
//    }
    
    public function deleteUnmatchingProductIds($productIdsToDelete, $dynamicCustomOptionsId) {
        $adapter = $this->getConnection();
        $condition = ['product_id IN(?)' => $productIdsToDelete, 'dynamiccustomoptions_id=?' => $dynamicCustomOptionsId];
        $adapter->delete($this->getTable('filoblu_dynamiccustomoptions_products'), $condition);
    }

}
